tiled.queries.Regex
===================

.. currentmodule:: tiled.queries

.. autoclass:: Regex

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Regex.__init__
      ~Regex.decode
      ~Regex.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Regex.case_sensitive
      ~Regex.key
      ~Regex.pattern
   
   